#!/bin/sh
# Simple wrapper script used to start JOSM in Debian
set -e

# First, the alternative (if known to work) or users preference as defined by $JAVA_HOME. Next, use OpenJDK or Sun's proprietary JDK.
# Override to a specific one using $JAVACMD
ALTERNATIVE_JDK="`readlink -n -f /etc/alternatives/java`"

# Let's get the current architecture -- needed for multiarchified Java
ARCH="`dpkg --print-architecture`"

# If OpenJDK 6 is only available headless, do not try it
if dpkg --get-selections openjdk-6-jre | grep install$ > /dev/null ; then
	JAVA_CMDS="$JAVA_HOME/bin/java /usr/lib/jvm/java-7-openjdk-$ARCH/bin/java /usr/lib/jvm/java-6-openjdk/bin/java /usr/lib/jvm/java-6-openjdk-$ARCH/bin/java /usr/lib/jvm/java-6-sun/bin/java "
else
	JAVA_CMDS="$JAVA_HOME/bin/java /usr/lib/jvm/java-6-sun/bin/java"
fi

JAVA_OPTS="$JAVA_OPTS -Djava.net.preferIPv4Stack=true -Djava.net.useSystemProxies=true"

for jcmd in $JAVA_CMDS; do
	if [ "z$ALTERNATIVE_JDK" = "z`readlink -n -f $jcmd`" ] && [ -z "${JAVACMD}" ]; then
        JAVACMD="$jcmd"
    fi
done

for jcmd in $JAVA_CMDS; do
    if [ -x "$jcmd" -a -z "${JAVACMD}" ]; then
        JAVACMD="$jcmd"
    fi
done

if [ "$JAVACMD" ]; then
    echo "Using $JAVACMD to execute josm." || true
    exec $JAVACMD $JAVA_OPTS -jar /usr/share/josm/josm.jar "$@"
else
    echo "No valid JVM found to run JOSM." || true
    exit 1
fi
